package com.hw.qms.service;

import java.util.List;
import com.hw.qms.domain.QmsCheckRule;
import com.hw.qms.domain.QmsCheckRuleDetail;
import com.hw.qms.domain.QmsCheckRuleProject;

/**
 * 检验规则维护Service接口
 *
 * @author xins
 * @date 2024-01-26
 */
public interface IQmsCheckRuleService
{
    /**
     * 查询检验规则维护
     *
     * @param checkRuleId 检验规则维护主键
     * @return 检验规则维护
     */
    public QmsCheckRule selectQmsCheckRuleByCheckRuleId(Long checkRuleId);

    /**
     * 查询检验规则维护列表
     *
     * @param qmsCheckRule 检验规则维护
     * @return 检验规则维护集合
     */
    public List<QmsCheckRule> selectQmsCheckRuleList(QmsCheckRule qmsCheckRule);

    /**
     * 新增检验规则维护
     *
     * @param qmsCheckRule 检验规则维护
     * @return 结果
     */
    public int insertQmsCheckRule(QmsCheckRule qmsCheckRule);

    /**
     * 修改检验规则维护
     *
     * @param qmsCheckRule 检验规则维护
     * @return 结果
     */
    public int updateQmsCheckRule(QmsCheckRule qmsCheckRule);

    /**
     * 批量删除检验规则维护
     *
     * @param checkRuleIds 需要删除的检验规则维护主键集合
     * @return 结果
     */
    public int deleteQmsCheckRuleByCheckRuleIds(Long[] checkRuleIds);

    /**
     * 删除检验规则维护信息
     *
     * @param checkRuleId 检验规则维护主键
     * @return 结果
     */
    public int deleteQmsCheckRuleByCheckRuleId(Long checkRuleId);

    /**
     * 批量插入检验规则明细
     * @param checkRuleDetailList
     */
    public int batchInsertCheckRuleDetail(List<QmsCheckRuleDetail> checkRuleDetailList);


    /**
     * 批量插入检验规则项目
     * @param checkRuleProjectList
     */
    public int batchInsertCheckRuleProject(List<QmsCheckRuleProject> checkRuleProjectList);

    /**
     * 查询检验规则维护，连接check_rule_project
     *
     * @param qmsCheckRuleDetail 检验规则明细
     * @return 检验规则维护
     */
    public QmsCheckRule selectQmsCheckRuleByTarget(QmsCheckRuleDetail qmsCheckRuleDetail);
}
